#     Procedura per ridurre una serie di n (n=16) frame di standard
#     per la Illumination Correction - Leo Vanzi Agosto 2000

#     It is important to set properly all the parameter for PHOT, in
#     particular it is advisable to use an aperture of 3" radius for
#     the photometry, it is also important to use ONLY one aperture
#     or SURFIT would get confused

#
#

procedure illumination(image_list)

string    image_list    {prompt="list of input images"}
string    flat_field    {prompt="flat field"}
string    output_file   {prompt="output file for photometric data"}
string    illum_frame   {prompt="output illumination correction surface"}
struct    *flist

begin
 
    int i,n

    n=16

    !rm -f temp*.fits.mag.1

#   start loop to read image names from the input file
     i=1

     list = image_list
     while( fscan(list, s1) != EOF ) {
        print(s1)
        imcopy(s1,"temp"//i//".fits")
        i=i+1
     } 

#  create a sky frame
   print('creating a sky frame....')
   ! ls temp*.fits > templist.lst

#  imcombine("@templist.lst","tempbck.fits",combine="median",reject="minmax")
   imcombine("@templist.lst","tempbck.fits",combine="median",reject="pclip",scale="median",zero="none",mclip=yes,lsigma=5,hsigma=5)

#  sky subtraction from the images and division for the flat
   print('sky subtracting and flat-fielding....')
     i=1
     while(i<=n){
       imarith("temp"//i//".fits","-","tempbck.fits","temp_bck"//i//".fits")
       imarith("temp_bck"//i//".fits","/",flat_field,"temp_fl"//i//".fits")
       i=i+1
     }

#  display the images and do photometry
   print('use space on the star and control-D to continue....')
     i=1
     while(i<=n){
     display("temp_fl"//i//".fits",1,fill=yes); phot("temp_fl"//i//".fits",interact=yes)
     i=i+1
     }
   

#   dir(*.mag.1,long-, >> tempmag.lst)
    !ls *mag.1 > tempmag.lst

    txdump(textfile="@tempmag.lst",fields="XCENTER,YCENTER,FLUX",expr=yes,>output_file) 

#   delete the temporary images and files
    imdelete("temp*.fits",yes,ver-)
    !rm -f temp*.lst
    !rm -f temp*.fits.mag.1

#   fit the illumination correction surface
    print('fitting the illumination surface...')
    surfit(output_file,image=illum_frame,function="polynomial",xorder=2,yorder=2,xterms="full",ncols=1024,nlines=1024)

    normalize(illum_frame)

end
